/*
MZoomControl
Control to set the zoomlevel, allowing for predefined values.

Copyright 2008 - Marcelo Montagna  - http://maps.forum.nu

Free to use as long as copyright notices are left unchanged.
Please save the file to your own server. Do not link directly,
or unexpected things might happen to your control :-)

Note: This script contains code to prevent hotlinking. (marked with 'REMOVE')
You need to remove it when saving the file to your server.

------------------------------------------------------------
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
------------------------------------------------------------

*/

function MZoomControl(MOptions) {
	MOptions = MOptions ? MOptions : {};
	this.parent = MOptions.container ? MOptions.container : null;
	this.direction = MOptions.direction ? MOptions.direction : 'H';
	this.validValues = MOptions.validValues ? MOptions.validValues : [];
	this.maxRes = 0;
	this.position = MOptions.position ? MOptions.position : new GControlPosition(G_ANCHOR_BOTTOM_LEFT, new GSize(0, 0));
}

MZoomControl.prototype = new GControl();

MZoomControl.prototype.initialize = function(map) {
	var that = this;
	this.map = map;

	if (this.validValues.length == 0) {
		var mapTypes = this.map.getMapTypes();
		for (var n = 0; n < mapTypes.length ; n++ ) {
			this.maxRes = Math.max(mapTypes[n].getMaximumResolution(),this.maxRes);
		}
		for (var n = 0; n < this.maxRes+1 ; n++ ) {
			this.validValues.push(n);
		}
	}

	//GEvent.addListener(this.map, "zoomend", function(o,n) {that.mapZoomEnd(o,n)});
	GEvent.addListener(this.map, "maptypechanged", function(o,n) {that.mapTypeChanged()});

	this.container = document.createElement('div');

	var oTable = document.createElement('table');
	this.container.appendChild(oTable);

	oTable.setAttribute('cellSpacing','1');
	oTable.setAttribute('cellPadding','0');


	var oTbody = document.createElement('tbody');
	oTable.appendChild(oTbody);
	
	var oRow = document.createElement('tr');
	oTbody.appendChild(oRow);
	
	var oRow2 = document.createElement('tr');
	oTbody.appendChild(oRow2);

//------ Zoom In -------------------	
	var zoomIn = document.createElement('td');
	zoomIn.id = 'MZC_in';
	zoomIn.innerHTML = '<img src="http://en.roolz.org/zoom-in.png">';
	GEvent.addDomListener(zoomIn, "click", function() {
												//zoomIn.innerHTML = '<img src="Google_80x80_Zoom_In_02.png">';
												that.discreteZoomIn();
												//zoomIn.innerHTML = '<img src="Google_80x80_Zoom_In_01.png">';
												}
	);
	oRow.appendChild(zoomIn);
//-------------------------	

//------------- Arrow Up --------------
	var arrowUp = document.createElement('td');
	arrowUp.id = 'MZC_up';
	arrowUp.innerHTML = '<img src="http://en.roolz.org/go-up.png">';
	GEvent.addDomListener(arrowUp, "click", function() { that.move(0,+1); });
	oRow.appendChild(arrowUp);
//-------------------------------------
	

//------ Zoom Out -------------------	
	var zoomOut = document.createElement('td');
	zoomOut.id = 'MZC_out';
	zoomOut.innerHTML = '<img src="http://en.roolz.org/zoom-out.png">';
	GEvent.addDomListener(zoomOut, "click", function() { that.discreteZoomOut(); } );
	if (this.direction == 'V') {
		var oRow = document.createElement('tr');
		oTbody.appendChild(oRow);
	}
	oRow.appendChild(zoomOut);
//-------------------------	

//------Left, Down, Rigth-------------
	var arrowLeft = document.createElement('td');
	arrowLeft.id = 'MZC_left';
	arrowLeft.innerHTML = '<img src="http://en.roolz.org/go-previous.png">';
	GEvent.addDomListener(arrowLeft, "click", function() {that.move(+1,0)});
	if (this.direction == 'V') {
		var oRow2 = document.createElement('tr');
		oTbody.appendChild(oRow2);
	}
	oRow2.appendChild(arrowLeft);
	
	var arrowDown = document.createElement('td');
	arrowDown.id = 'MZC_down';
	arrowDown.innerHTML = '<img src="http://en.roolz.org/go-down.png">';
	GEvent.addDomListener(arrowDown, "click", function() { that.move(0,-1); });
	if (this.direction == 'V') {
		var oRow2 = document.createElement('tr');
		oTbody.appendChild(oRow2);
	}
	oRow2.appendChild(arrowDown);
	
	var arrowRight = document.createElement('td');
	arrowRight.id = 'MZC_right';
	arrowRight.innerHTML = '<img src="http://en.roolz.org/go-next.png">';
	GEvent.addDomListener(arrowRight, "click", function() {that.move(-1,0)});
	if (this.direction == 'V') {
		var oRow2 = document.createElement('tr');
		oTbody.appendChild(oRow2);
	}
	oRow2.appendChild(arrowRight);
	
//------------------------------------

	if (this.parent) {
		this.parent.appendChild(this.container);
	}
	else {
		this.map.getContainer().appendChild(this.container);
	}
	that.mapZoomEnd(null,this.map.getZoom());

	return this.container;
}

MZoomControl.prototype.getDefaultPosition = function() {
	return this.position;
}


////////////////////////////

MZoomControl.prototype.move = function(x,y) {
	this.map.panDirection(x,y);
	
}
MZoomControl.prototype.discreteZoomIn = function() {
	var currentZoom = this.map.getZoom();
	for (var n = 0 ; n < this.validValues.length ; n++ ) {
		if (this.validValues[n] > currentZoom) {
			this.map.setCenter(this.map.getCenter(),this.validValues[n]);
			return;
		}
	}
	this.map.setCenter(this.map.getCenter(),this.validValues[this.validValues.length-1]);
}

MZoomControl.prototype.discreteZoomOut = function() {
	var currentZoom = this.map.getZoom();
	for (var n = this.validValues.length-1 ; n > -1 ; n-- ) {
		if (this.validValues[n] < currentZoom) {
			this.map.setCenter(this.map.getCenter(),this.validValues[n]);
			return;
		}
	}
	this.map.setCenter(this.map.getCenter(),this.validValues[0]);
	
}

MZoomControl.prototype.setZoom = function(z) {
	this.map.setCenter(this.map.getCenter(),z)
}

MZoomControl.prototype.mapZoomEnd = function(o,n) {
	n = Math.floor(n);

	var z = 0;
	var oldCell = document.getElementById('MZC_'+z);
	while (oldCell) {
		this.setStyle(oldCell);
		z++;
		oldCell = document.getElementById('MZC_'+z);
	}
	
	
	var newCell = document.getElementById('MZC_'+n);
	if (oldCell) {
		this.setStyle(oldCell);		
	}
	if (newCell) {
		this.setStyleSel(newCell);		
	}
	else {
		if (n > o) {
			this.discreteZoomIn();
		}
		else {
			this.discreteZoomOut();
		}
	}
};

MZoomControl.prototype.show = function () {
	this.container.style.display = '';
}

MZoomControl.prototype.hide = function () {
	this.container.style.display = 'none';
}

MZoomControl.prototype.toggle = function () {
	this.container.style.display = this.container.style.display == '' ? 'none' : '';
}
